/*  The Clipboard Project - Cut, copy, and paste anything, anytime, anywhere, all from the terminal.
    Copyright (C) 2023 Jackson Huff and other contributors on GitHub.com
    SPDX-License-Identifier: GPL-3.0-or-later
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.*/
#include "clipboard.hpp"

int main(int argc, char* argv[]) {
    try {
        setupHandlers();

        setupVariables(argc, argv);

        setupTerminal();

        setLocale();

        setClipboardAttributes();

        setFlags();

        startIndicator();

        verifyClipboardName();

        setFilepaths();

        action = getAction();

        if (auto pos = std::find_if(arguments.begin(), arguments.end(), [](const auto& arg) { return arg == "--"; }); pos != arguments.end()) arguments.erase(pos);

        copying.items.assign(arguments.begin(), arguments.end());

        io_type = getIOType();

        verifyAction();

#if defined(__linux__)
        setupGUIClipboardDaemon();
        syncWithRemoteClipboard();
        if (action != Action::Info) path.getLock();
#else
        if (action != Action::Info) path.getLock();
        syncWithExternalClipboards();
#endif

        fixMissingItems();

        ignoreItemsPreemptively(copying.items);

        checkForNoItems();

        if (needsANewEntry()) path.makeNewEntry();

        (clipboard_state.exchange(ClipboardState::Action), cv.notify_one());

        (fs::create_directories(global_path.temporary), fs::create_directories(global_path.persistent));

        if (io_type != IOType::Text) deduplicate(copying.items);

        checkItemSize(totalItemSize());

        checkClipboardScriptEligibility();

        runClipboardScript();

        performAction();

        runClipboardScript();

        if (isAWriteAction()) path.applyIgnoreRules();

        copying.mime = getMIMEType();

        updateExternalClipboards();

        if (!copying.failedItems.empty()) clipboard_state = ClipboardState::Error;

        stopIndicator();

        deduplicate(copying.failedItems);

        showFailures();

        showSuccesses();

        path.trimHistoryEntries();
    } catch (const std::exception& e) {
        clipboard_state = ClipboardState::Error;
        stopIndicator();
        fprintf(stderr, internal_error_message().data(), e.what());
        exit(EXIT_FAILURE);
    }
    if (clipboard_state == ClipboardState::Error)
        exit(EXIT_FAILURE);
    else
        exit(EXIT_SUCCESS);
}